@@ -21,8 +21,6 @@ from neutron.agent.linux import interface as n_interface
 from neutron.agent.linux import ip_lib
 from neutron.agent.linux import utils
 
-from midonet.neutron._i18n import _LE, _LW
-
 LOG = logging.getLogger(__name__)
 
 
@@ -30,7 +28,9 @@ class MidonetInterfaceDriver(n_interface.LinuxInterfaceDriver):
 
     def plug_new(self, network_id, port_id, device_name, mac_address,
                  bridge=None, namespace=None, prefix=None, mtu=None):
-        """This method is called by the Dhcp agent or by the L3 agent
+        """Plug an interface.
+
+        This method is called by the Dhcp agent or by the L3 agent
         when a new network is created
         """
         ip = ip_lib.IPWrapper()
@@ -47,13 +47,13 @@ class MidonetInterfaceDriver(n_interface.LinuxInterfaceDriver):
             ns_dev.link.set_mtu(mtu)
             root_dev.link.set_mtu(mtu)
         else:
-            LOG.warning(_LW("No MTU configured for port %s"), port_id)
+            LOG.warning("No MTU configured for port %s", port_id)
 
         ns_dev.link.set_up()
         root_dev.link.set_up()
 
         cmd = ['mm-ctl', '--bind-port', port_id, device_name]
-        utils.execute(cmd, run_as_root=True)
+        utils.execute(cmd, run_as_root=True)  # nosec
 
     def unplug(self, device_name, bridge=None, namespace=None, prefix=None):
         # the port will be deleted by the dhcp agent that will call the plugin
@@ -61,7 +61,7 @@ class MidonetInterfaceDriver(n_interface.LinuxInterfaceDriver):
         try:
             device.link.delete()
         except RuntimeError:
-            LOG.error(_LE("Failed unplugging interface '%s'"), device_name)
+            LOG.error("Failed unplugging interface '%s'", device_name)
         LOG.debug("Unplugged interface '%s'", device_name)
 
         ip_lib.IPWrapper(namespace=namespace).garbage_collect_namespace()
